import {apiUrl} from '../../env.js'
import axios from 'axios'

export const getAxiosConfig = () => {
    let config = {
        headers : {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
        }
    }
    config.headers["Access-Token"] = sessionStorage.getItem('@portalmec/accessToken');
    config.headers.Client = sessionStorage.getItem('@portalmec/clientToken')
    config.headers.Uid = sessionStorage.getItem('@portalmec/uid')
    config.headers.Expiry = sessionStorage.getItem('@portalmec/expiry')
    return config
}

export function getAxiosConfigFromJSON () {
    let config = {
        headers : JSON.parse(sessionStorage.getItem('@portalmec/auth_headers'))
    }
    return config
}

function checkPreviousTokens (new_token) {

    let prev_tokens = JSON.parse(sessionStorage.getItem('@portalmec/tokens'))

    if (prev_tokens) {
        console.log('hasOwnProperty = ', prev_tokens.hasOwnProperty(new_token))
        if (!prev_tokens.hasOwnProperty(new_token)) {
            prev_tokens[new_token] = 1
            console.log('adicionando token', new_token, ' a hash')
            sessionStorage.setItem('@portalmec/tokens', JSON.stringify(prev_tokens))
            return true
        }
        else {
            return false
        }
    }
    else {
        let tokens = {}
        tokens[new_token] = 1
        console.log('adicionando token', new_token, ' a hash')
        sessionStorage.setItem('@portalmec/tokens', JSON.stringify(tokens))
        return true
    }

}

export function updateHeaders (newHeaders) {

    if (checkPreviousTokens(newHeaders['access-token'])) {

        sessionStorage.setItem('@portalmec/accessToken', newHeaders['access-token'])

        let auth_headers = JSON.parse(sessionStorage.getItem('@portalmec/auth_headers'))

        if (auth_headers) {
            auth_headers['access-token'] = newHeaders['access-token']
        }
        else {
            auth_headers = {
                client: newHeaders.client,
                "access-token": newHeaders['access-token'],
                uid: newHeaders.uid,
                expiry: newHeaders.expiry,
                "token-type": "Bearer"
            }
        }

        sessionStorage.setItem('@portalmec/auth_headers', JSON.stringify(auth_headers))
    }

}

export const axiosGetRequest = (url, onSuccess, onError) => {
    let config = getAxiosConfigFromJSON()

    axios.get( (`${apiUrl}${url}`), config ).then(
        (response) => {

            if ( response.headers['access-token'] && response.status !== 304) {
                console.log('filtered = ', response)
                updateHeaders(response.headers)
            }

            onSuccess(response.data)
        },
        (error) => {
            onError(error)
        }
    )
}

export const axiosDeleteRequest = (url, onSuccess, onError) => {
    let config = getAxiosConfigFromJSON()

    axios.delete( (`${apiUrl}${url}`), config ).then(
        (response) => {

            if ( response.headers['access-token'] && response.status !== 304) {
                console.log('filtered = ', response)
                updateHeaders(response.headers)
            }

            onSuccess(response.data)
        },
        (error) => {
            onError(error)
        }
    )
}

export const axiosPutRequest = (url, payload, onSuccess, onError) => {
    let config = getAxiosConfigFromJSON()

    axios.put( (`${apiUrl}${url}`), payload, config ).then(
        (response) => {

            if ( response.headers['access-token'] && response.status !== 304) {
                console.log('filtered = ', response)
                updateHeaders(response.headers)
            }

            onSuccess(response.data)
        },
        (error) => {
            onError(error)
        }
    )
}

export const axiosPostRequest = (url, payload, onSuccess, onError) => {
    let config = getAxiosConfigFromJSON()

    axios.post( (`${apiUrl}${url}`), payload, config ).then(
        (response) => {

            if ( response.headers['access-token'] && response.status !== 304) {
                console.log('filtered = ', response)
                updateHeaders(response.headers)
            }

            onSuccess(response.data)
        },
        (error) => {
            onError(error)
        }
    )
}

function filterFunction (value) {
    if (value.headers['access-token'] && value.status !== 304) {
        return true
    }
    else {
        return false
    }
}

export const axiosAllRequest = (urls, onSuccess, onError) => {
    axios.all(
        urls.map( url => axios.get(`${apiUrl}${url}`, getAxiosConfigFromJSON()) )
    ).then(
        (responseArray) => {
            var aux = responseArray.filter(filterFunction)
            if (aux[0]) {
                console.log('filtered = ', aux)
                updateHeaders(aux[0].headers)
            }

            onSuccess(responseArray)
        },
        (error) => {
            onError(error)
        }
    )
}

export const validateGoogleLoginToken = (config, onSuccess, onError) => {
    axios.get( (`${apiUrl}/auth/validate_token/`), config ).then(
        (response) => {

            if ( response.headers['access-token'] ) {
                updateHeaders(response.headers)
            }

            onSuccess(response.data)
        },
        (error) => {
            onError(error)
        }
    )
}

export const authentication = (url, payload, onSuccess, onError) => {
    let config = getAxiosConfigFromJSON()

    axios.post( (`${apiUrl}${url}`), payload, config ).then(
        (response) => {

            const auth_headers = {
                client: response.headers.client,
                "access-token": response.headers['access-token'],
                uid: response.headers.uid,
                expiry: response.headers.expiry,
                "token-type": "Bearer"
            }

            sessionStorage.setItem('@portalmec/auth_headers', JSON.stringify(auth_headers))

            onSuccess(response.data)
        },
        (error) => {
            onError(error)
        }
    )
}
